Listener

Struct Listener 

pub struct Listener { /* private fields */ }
Represents the TCP listener and exposes certain functions to interact with the outside world. They are mostly just wrappers around the underlying TCP modules.

Implementations

Source

impl Listener

pub fn new( center: Center, channel: Channel<Transaction>, limit: usize, table: Safe, signaling: Signaling, ) -> Result<Self, Error>

Spaws a new TCP listener based on the link details of the center.

pub fn start(self)